@@ -100,7 +100,7 @@ Mojo::Cookie::Response - HTTP response cookie
 =head1 DESCRIPTION
 
 L<Mojo::Cookie::Response> is a container for HTTP response cookies as
-described in L<RFC 6265|http://tools.ietf.org/search/rfc6265>.
+described in L<RFC 6265|http://tools.ietf.org/html/rfc6265>.
 
 =head1 ATTRIBUTES
 
