@@ -181,7 +181,7 @@ Mojo::Headers - Headers
 =head1 DESCRIPTION
 
 L<Mojo::Headers> is a container for HTTP headers as described in
-L<RFC 2616|http://tools.ietf.org/search/rfc2616>.
+L<RFC 2616|http://tools.ietf.org/html/rfc2616>.
 
 =head1 ATTRIBUTES
 
@@ -334,7 +334,7 @@ Shortcut for the C<Content-Type> header.
   $headers   = $headers->cookie('f=b');
 
 Shortcut for the C<Cookie> header from
-L<RFC 6265|http://tools.ietf.org/search/rfc6265>.
+L<RFC 6265|http://tools.ietf.org/html/rfc6265>.
 
 =head2 date
 
@@ -442,7 +442,7 @@ Get leftover data from header parser.
   $headers = $headers->link('<http://127.0.0.1/foo/3>; rel="next"');
 
 Shortcut for the C<Link> header from
-L<RFC 5988|http://tools.ietf.org/search/rfc5988>.
+L<RFC 5988|http://tools.ietf.org/html/rfc5988>.
 
 =head2 location
 
@@ -466,7 +466,7 @@ Return a list of all currently defined headers.
   $headers   = $headers->origin('http://example.com');
 
 Shortcut for the C<Origin> header from
-L<RFC 6454|http://tools.ietf.org/search/rfc6454>.
+L<RFC 6454|http://tools.ietf.org/html/rfc6454>.
 
 =head2 parse
 
@@ -501,7 +501,7 @@ Shortcut for the C<Range> header.
   $headers     = $headers->referrer('http://example.com');
 
 Shortcut for the C<Referer> header, there was a typo in
-L<RFC 2068|http://tools.ietf.org/search/rfc2068> which resulted in C<Referer>
+L<RFC 2068|http://tools.ietf.org/html/rfc2068> which resulted in C<Referer>
 becoming an official header.
 
 =head2 remove
@@ -516,7 +516,7 @@ Remove a header.
   $headers   = $headers->sec_websocket_accept('s3pPLMBiTxaQ9kYGzzhZRbK+xOo=');
 
 Shortcut for the C<Sec-WebSocket-Accept> header from
-L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
+L<RFC 6455|http://tools.ietf.org/html/rfc6455>.
 
 =head2 sec_websocket_extensions
 
@@ -524,7 +524,7 @@ L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
   $headers       = $headers->sec_websocket_extensions('foo');
 
 Shortcut for the C<Sec-WebSocket-Extensions> header from
-L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
+L<RFC 6455|http://tools.ietf.org/html/rfc6455>.
 
 =head2 sec_websocket_key
 
@@ -532,7 +532,7 @@ L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
   $headers = $headers->sec_websocket_key('dGhlIHNhbXBsZSBub25jZQ==');
 
 Shortcut for the C<Sec-WebSocket-Key> header from
-L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
+L<RFC 6455|http://tools.ietf.org/html/rfc6455>.
 
 =head2 sec_websocket_protocol
 
@@ -540,7 +540,7 @@ L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
   $headers  = $headers->sec_websocket_protocol('sample');
 
 Shortcut for the C<Sec-WebSocket-Protocol> header from
-L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
+L<RFC 6455|http://tools.ietf.org/html/rfc6455>.
 
 =head2 sec_websocket_version
 
@@ -548,7 +548,7 @@ L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
   $headers    = $headers->sec_websocket_version(13);
 
 Shortcut for the C<Sec-WebSocket-Version> header from
-L<RFC 6455|http://tools.ietf.org/search/rfc6455>.
+L<RFC 6455|http://tools.ietf.org/html/rfc6455>.
 
 =head2 server
 
@@ -563,7 +563,7 @@ Shortcut for the C<Server> header.
   $headers   = $headers->set_cookie('f=b; path=/');
 
 Shortcut for the C<Set-Cookie> header from
-L<RFC 6265|http://tools.ietf.org/search/rfc6265>.
+L<RFC 6265|http://tools.ietf.org/html/rfc6265>.
 
 =head2 status
 
@@ -571,7 +571,7 @@ L<RFC 6265|http://tools.ietf.org/search/rfc6265>.
   $headers   = $headers->status('200 OK');
 
 Shortcut for the C<Status> header from
-L<RFC 3875|http://tools.ietf.org/search/rfc3875>.
+L<RFC 3875|http://tools.ietf.org/html/rfc3875>.
 
 =head2 te
 
