@@ -10,8 +10,6 @@ use Mojo::Util
 has base => sub { Mojo::URL->new };
 has [qw(fragment host port scheme userinfo)];
 
-sub new { shift->SUPER::new->parse(@_) }
-
 sub authority {
   my $self = shift;
 
@@ -73,6 +71,8 @@ sub ihost {
 
 sub is_abs { !!shift->scheme }
 
+sub new { shift->SUPER::new->parse(@_) }
+
 sub parse {
   my ($self, $url) = @_;
   return $self unless $url;
@@ -249,8 +249,8 @@ Mojo::URL - Uniform Resource Locator
 =head1 DESCRIPTION
 
 L<Mojo::URL> implements a subset of
-L<RFC 3986|http://tools.ietf.org/search/rfc3986> and
-L<RFC 3987|http://tools.ietf.org/search/rfc3987> for Uniform Resource Locators
+L<RFC 3986|http://tools.ietf.org/html/rfc3986> and
+L<RFC 3987|http://tools.ietf.org/html/rfc3987> for Uniform Resource Locators
 with support for IDNA and IRIs.
 
 =head1 ATTRIBUTES
@@ -304,13 +304,6 @@ Userinfo part of this URL.
 L<Mojo::URL> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
-=head2 new
-
-  my $url = Mojo::URL->new;
-  my $url = Mojo::URL->new('http://127.0.0.1:3000/foo?f=b&baz=2#foo');
-
-Construct a new L<Mojo::URL> object and L</"parse"> URL if necessary.
-
 =head2 authority
 
   my $authority = $url->authority;
@@ -340,6 +333,13 @@ Host part of this URL in punycode format.
 
 Check if URL is absolute.
 
+=head2 new
+
+  my $url = Mojo::URL->new;
+  my $url = Mojo::URL->new('http://127.0.0.1:3000/foo?f=b&baz=2#foo');
+
+Construct a new L<Mojo::URL> object and L</"parse"> URL if necessary.
+
 =head2 parse
 
   $url = $url->parse('http://127.0.0.1:3000/foo/bar?fo=o&baz=23#foo');
@@ -435,10 +435,25 @@ provided base URL.
 =head2 to_string
 
   my $str = $url->to_string;
-  my $str = "$url";
 
 Turn URL into a string.
 
+=head1 OPERATORS
+
+L<Mojo::URL> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$url;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$url";
+
+Alias for L</to_string>.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
