@@ -4,17 +4,7 @@ use Mojo::Base 'Mojolicious::Command';
 use Getopt::Long qw(GetOptionsFromArray :config no_auto_abbrev no_ignore_case);
 
 has description => "Run code against application.\n";
-has usage       => <<EOF;
-usage: $0 eval [OPTIONS] CODE
-
-  mojo eval 'say app->ua->get("/")->res->body'
-  mojo eval -v 'app->home'
-  mojo eval -V 'app->renderer->paths'
-
-These options are available:
-  -v, --verbose   Print return value to STDOUT.
-  -V              Print returned data structure to STDOUT.
-EOF
+has usage => sub { shift->extract_usage };
 
 sub run {
   my ($self, @args) = @_;
@@ -40,10 +30,15 @@ Mojolicious::Command::eval - Eval command
 
 =head1 SYNOPSIS
 
-  use Mojolicious::Command::eval;
+  Usage: APPLICATION eval [OPTIONS] CODE
 
-  my $eval = Mojolicious::Command::eval->new;
-  $eval->run(@ARGV);
+    ./myapp.pl eval 'say app->ua->get("/")->res->body'
+    ./myapp.pl eval -v 'app->home'
+    ./myapp.pl eval -V 'app->renderer->paths'
+
+  Options:
+    -v, --verbose   Print return value to STDOUT.
+    -V              Print returned data structure to STDOUT.
 
 =head1 DESCRIPTION
 
