@@ -6,41 +6,7 @@ use Mojo::Server::Prefork;
 
 has description =>
   "Start application with preforking HTTP and WebSocket server.\n";
-has usage => <<EOF;
-usage: $0 prefork [OPTIONS]
-
-These options are available:
-  -A, --accepts <number>               Number of connections for workers to
-                                       accept, defaults to 1000.
-  -a, --accept-interval <seconds>      Accept interval, defaults to 0.025.
-  -b, --backlog <size>                 Listen backlog size, defaults to
-                                       SOMAXCONN.
-  -c, --clients <number>               Maximum number of concurrent clients,
-                                       defaults to 1000.
-  -G, --graceful-timeout <seconds>     Graceful timeout, defaults to 20.
-  -g, --group <name>                   Group name for process.
-      --heartbeat-interval <seconds>   Heartbeat interval, defaults to 5.
-  -H, --heartbeat-timeout <seconds>    Heartbeat timeout, defaults to 20.
-  -i, --inactivity <seconds>           Inactivity timeout, defaults to the
-                                       value of MOJO_INACTIVITY_TIMEOUT or 15.
-      --lock-file <path>               Path to lock file, defaults to a random
-                                       file.
-  -L, --lock-timeout <seconds>         Lock timeout, defaults to 1.
-  -l, --listen <location>              One or more locations you want to
-                                       listen on, defaults to the value of
-                                       MOJO_LISTEN or "http://*:3000".
-      --multi-accept <number>          Number of connection to accept at once,
-                                       defaults to 50.
-  -P, --pid-file <path>                Path to process id file, defaults to a
-                                       random file.
-  -p, --proxy                          Activate reverse proxy support,
-                                       defaults to the value of
-                                       MOJO_REVERSE_PROXY.
-  -r, --requests <number>              Maximum number of requests per
-                                       keep-alive connection, defaults to 25.
-  -u, --user <name>                    Username for process.
-  -w, --workers <number>               Number of workers, defaults to 4.
-EOF
+has usage => sub { shift->extract_usage };
 
 sub run {
   my ($self, @args) = @_;
@@ -80,10 +46,44 @@ Mojolicious::Command::prefork - Prefork command
 
 =head1 SYNOPSIS
 
-  use Mojolicious::Command::prefork;
+  Usage: APPLICATION prefork [OPTIONS]
 
-  my $prefork = Mojolicious::Command::prefork->new;
-  $prefork->run(@ARGV);
+    ./myapp.pl prefork -m production -l http://*:8080
+    ./myapp.pl prefork -l http://127.0.0.1:8080 -l https://[::]:8081
+
+  Options:
+    -A, --accepts <number>               Number of connections for workers to
+                                         accept, defaults to 1000.
+    -a, --accept-interval <seconds>      Accept interval, defaults to 0.025.
+    -b, --backlog <size>                 Listen backlog size, defaults to
+                                         SOMAXCONN.
+    -c, --clients <number>               Maximum number of concurrent clients,
+                                         defaults to 1000.
+    -G, --graceful-timeout <seconds>     Graceful timeout, defaults to 20.
+    -g, --group <name>                   Group name for process.
+        --heartbeat-interval <seconds>   Heartbeat interval, defaults to 5.
+    -H, --heartbeat-timeout <seconds>    Heartbeat timeout, defaults to 20.
+    -i, --inactivity <seconds>           Inactivity timeout, defaults to the
+                                         value of MOJO_INACTIVITY_TIMEOUT or
+                                         15.
+        --lock-file <path>               Path to lock file, defaults to a
+                                         random file.
+    -L, --lock-timeout <seconds>         Lock timeout, defaults to 1.
+    -l, --listen <location>              One or more locations you want to
+                                         listen on, defaults to the value of
+                                         MOJO_LISTEN or "http://*:3000".
+        --multi-accept <number>          Number of connection to accept at
+                                         once, defaults to 50.
+    -P, --pid-file <path>                Path to process id file, defaults to
+                                         a random file.
+    -p, --proxy                          Activate reverse proxy support,
+                                         defaults to the value of
+                                         MOJO_REVERSE_PROXY.
+    -r, --requests <number>              Maximum number of requests per
+                                         keep-alive connection, defaults to
+                                         25.
+    -u, --user <name>                    Username for process.
+    -w, --workers <number>               Number of workers, defaults to 4.
 
 =head1 DESCRIPTION
 
