@@ -7,22 +7,22 @@ use Mojo::Server;
 
 has hint => <<EOF;
 
-These options are available for all commands:
+Options (for all commands):
     -h, --help          Get more information on a specific command.
         --home <path>   Path to your applications home directory, defaults to
                         the value of MOJO_HOME or auto detection.
     -m, --mode <name>   Operating mode for your application, defaults to the
                         value of MOJO_MODE/PLACK_ENV or "development".
 
-See '$0 help COMMAND' for more information on a specific command.
+See 'APPLICATION help COMMAND' for more information on a specific command.
 EOF
 has message => <<EOF;
-usage: $0 COMMAND [OPTIONS]
+Usage: APPLICATION COMMAND [OPTIONS]
 
 Tip: CGI and PSGI environments can be automatically detected very often and
      work without commands.
 
-These commands are currently available:
+Commands:
 EOF
 has namespaces => sub { ['Mojolicious::Command'] };
 
@@ -95,7 +95,7 @@ sub run {
   # Print list of all available commands
   my $max = max map { length $_->[0] } @commands;
   print $self->message;
-  for my $command (@commands) {
+  for my $command (sort { $a->[0] cmp $b->[0] } @commands) {
     my $name        = $command->[0];
     my $description = $command->[1]->new->description;
     print "  $name", (' ' x ($max - length $name)), "   $description";
@@ -141,42 +141,31 @@ the C<Mojolicious::Command> namespace.
 
 These commands are available by default.
 
-=head2 help
-
-  $ mojo
-  $ mojo help
-  $ ./myapp.pl help
-
-List available commands with short descriptions.
-
-  $ mojo help <command>
-  $ ./myapp.pl help <command>
-
-List available options for the command with short descriptions.
-
 =head2 cgi
 
   $ ./myapp.pl cgi
 
-Start application with CGI backend, usually auto detected.
+Use L<Mojolicious::Command::cgi> to start application with CGI backend,
+usually auto detected.
 
 =head2 cpanify
 
   $ mojo cpanify -u sri -p secr3t Mojolicious-Plugin-Fun-0.1.tar.gz
 
-Upload files to CPAN.
+Use L<Mojolicious::Command::cpanify> for uploading files to CPAN.
 
 =head2 daemon
 
   $ ./myapp.pl daemon
 
-Start application with standalone HTTP and WebSocket server.
+Use L<Mojolicious::Command::daemon> to start application with standalone HTTP
+and WebSocket server.
 
 =head2 eval
 
   $ ./myapp.pl eval 'say app->home'
 
-Run code against application.
+Use L<Mojolicious::Command::eval> to run code against application.
 
 =head2 generate
 
@@ -195,74 +184,94 @@ List available options for generator command with short descriptions.
 
   $ mojo generate app <AppName>
 
-Generate application directory structure for a fully functional L<Mojolicious>
-application.
+Use L<Mojolicious::Command::generate::app> to generate application directory
+structure for a fully functional L<Mojolicious> application.
 
 =head2 generate lite_app
 
   $ mojo generate lite_app
 
-Generate a fully functional L<Mojolicious::Lite> application.
+Use L<Mojolicious::Command::generate::lite_app> to generate a fully functional
+L<Mojolicious::Lite> application.
 
 =head2 generate makefile
 
   $ mojo generate makefile
   $ ./myapp.pl generate makefile
 
-Generate C<Makefile.PL> file for application.
+Use L<Mojolicious::Command::generate::makefile> to generate C<Makefile.PL>
+file for application.
 
 =head2 generate plugin
 
   $ mojo generate plugin <PluginName>
 
-Generate directory structure for a fully functional L<Mojolicious> plugin.
+Use L<Mojolicious::Command::generate::plugin> to generate directory structure
+for a fully functional L<Mojolicious> plugin.
 
 =head2 get
 
   $ mojo get http://mojolicio.us
   $ ./myapp.pl get /foo
 
-Perform requests to remote host or local application.
+Use L<Mojolicious::Command::get> to perform requests to remote host or local
+application.
+
+=head2 help
+
+  $ mojo
+  $ mojo help
+  $ ./myapp.pl help
+
+List available commands with short descriptions.
+
+  $ mojo help <command>
+  $ ./myapp.pl help <command>
+
+List available options for the command with short descriptions.
 
 =head2 inflate
 
   $ ./myapp.pl inflate
 
-Turn templates and static files embedded in the C<DATA> sections of your
-application into real files.
+Use L<Mojolicious::Command::inflate> to turn templates and static files
+embedded in the C<DATA> sections of your application into real files.
 
 =head2 prefork
 
   $ ./myapp.pl prefork
 
-Start application with standalone preforking HTTP and WebSocket server.
+Use L<Mojolicious::Command::prefork> to start application with standalone
+preforking HTTP and WebSocket server.
 
 =head2 psgi
 
   $ ./myapp.pl psgi
 
-Start application with PSGI backend, usually auto detected.
+Use L<Mojolicious::Command::psgi> to start application with PSGI backend,
+usually auto detected.
 
 =head2 routes
 
   $ ./myapp.pl routes
 
-List application routes.
+Use L<Mojolicious::Command::routes> to list application routes.
 
 =head2 test
 
   $ ./myapp.pl test
   $ ./myapp.pl test t/fun.t
 
-Runs application tests from the C<t> directory.
+Use L<Mojolicious::Command::test> to run application tests from the C<t>
+directory.
 
 =head2 version
 
   $ mojo version
   $ ./myapp.pl version
 
-Show version information for installed core and optional modules, very useful
-for debugging.
+Use L<Mojolicious::Command::version> to show version information for installed
+core and optional modules, very useful for debugging.
 
 =head1 ATTRIBUTES
 
