@@ -126,6 +126,9 @@ just work without commands.
   $ ./myapp.pl cgi
   ...CGI output...
 
+  $ ./myapp.pl get /
+  Hello World!
+
   $ ./myapp.pl
   ...List of available commands (or automatically detected environment)...
 
@@ -792,10 +795,10 @@ session data gets serialized with L<Mojo::JSON>.
   @@ counter.html.ep
   Counter: <%= session 'counter' %>
 
-Note that you should use a custom L<Mojolicious/"secret"> to make signed
+Note that you should use custom L<Mojolicious/"secrets"> to make signed
 cookies really secure.
 
-  app->secret('My secret passphrase here');
+  app->secrets(['My secret passphrase here']);
 
 =head2 File uploads
 
@@ -1002,7 +1005,8 @@ fun!
 
 =head1 FUNCTIONS
 
-L<Mojolicious::Lite> implements the following functions.
+L<Mojolicious::Lite> implements the following functions, which are
+automatically exported.
 
 =head2 any
 
